@@ -710,14 +710,10 @@ nospace:
                 free(pglob->gl_statv[i]);
             }
         }
-        if (pglob->gl_pathv) {
-            free(pglob->gl_pathv);
-            pglob->gl_pathv = NULL;
-        }
-        if (pglob->gl_statv) {
-            free(pglob->gl_statv);
-            pglob->gl_statv = NULL;
-        }
+        free(pglob->gl_pathv);
+        pglob->gl_pathv = NULL;
+        free(pglob->gl_statv);
+        pglob->gl_statv = NULL;
         return GLOB_NOSPACE;
     }
 
@@ -862,18 +858,14 @@ globfree(glob_t *pglob)
     if (pglob->gl_pathv != NULL) {
         pp = pglob->gl_pathv + pglob->gl_offs;
         for (i = pglob->gl_pathc; i--; ++pp) {
-            if (*pp) {
-                free(*pp);
-            }
+            free(*pp);
         }
         free(pglob->gl_pathv);
         pglob->gl_pathv = NULL;
     }
     if (pglob->gl_statv != NULL) {
         for (i = 0; i < pglob->gl_pathc; i++) {
-            if (pglob->gl_statv[i] != NULL) {
-                free(pglob->gl_statv[i]);
-            }
+            free(pglob->gl_statv[i]);
         }
         free(pglob->gl_statv);
         pglob->gl_statv = NULL;
